[Libreoffice-commits] .: 5 commits - desktop/unx sal/prj sal/textenc sal/util scp2/source solenv/inc solenv/makefile.mk ure/source

Stephan Bergmann sbergmann at kemper.freedesktop.org
Wed Sep 21 09:27:41 PDT 2011


 desktop/unx/source/start.c           |   30 ++++++----
 sal/prj/build.lst                    |   33 ++++++-----
 sal/prj/d.lst                        |    6 --
 sal/textenc/makefile.mk              |    6 --
 sal/textenc/tables.cxx               |   12 +---
 sal/textenc/textenc.cxx              |   99 ++++++++++++++++++++++++-----------
 sal/util/makefile.mk                 |    9 ---
 sal/util/sal_textenc/makefile.mk     |   46 ++++++++++++++++
 sal/util/sal_textenc/saltextenc.map  |   32 +++++++++++
 sal/util/saltextenc.map              |    6 --
 scp2/source/kde/file_kde.scp         |    2 
 scp2/source/ooo/file_library_ooo.scp |    8 +-
 scp2/source/ooo/ure.scp              |    2 
 solenv/inc/version_so.hrc            |   64 ----------------------
 solenv/inc/versionlist.mk            |   30 ----------
 solenv/makefile.mk                   |    2 
 ure/source/README                    |    2 
 17 files changed, 199 insertions(+), 190 deletions(-)

New commits:
commit 9ffee68dc027662fd8e6aa044d7ee01b0ed5df16
Author: Stephan Bergmann <sbergman at redhat.com>
Date:   Wed Sep 21 16:34:46 2011 +0200

    Cleaned up sal_textenc, making it work on Mac OS X.

diff --git a/sal/prj/build.lst b/sal/prj/build.lst
index 9f9a6ac..47b8f58 100644
--- a/sal/prj/build.lst
+++ b/sal/prj/build.lst
@@ -12,21 +12,22 @@ sa  sal\qa                                  nmake   -   all sa_qa sa_util NULL
 sa	sal\osl\unx								nmake	-	u	sa_oslu sa_tc.u sa_inc NULL
 sa	sal\osl\all								nmake	-	all	sa_oslall sa_tc.u sa_inc NULL
 sa	sal\util								nmake	-	all	sa_util sa_tc.u sa_oslall sa_uwinapi.n sa_onlineupdate.n sa_osln.n sa_oslu.u sa_rtl sa_textenc NULL
+sa sal\util\sal_textenc nmake - all sa_util_saltextenc sa_util NULL
 sa sal\cppunittester nmake - all sa_cppunittester sa_cpprt.u sa_util NULL
-sa sal\qa\ByteSequence nmake - all sa_qa_ByteSequence sa_cppunittester sa_util NULL
-sa sal\qa\OStringBuffer nmake - all sa_qa_OStringBuffer sa_cppunittester sa_util NULL
-sa sal\qa\osl\getsystempathfromfileurl nmake - all sa_qa_osl_getsystempathfromfileurl sa_cppunittester sa_util NULL
-sa sal\qa\osl\file nmake - u sa_qa_osl_file sa_cppunittester sa_util NULL
-sa sal\qa\osl\module nmake - u sa_qa_osl_module sa_cppunittester sa_util NULL
-sa sal\qa\osl\condition nmake - all sa_qa_osl_condition sa_cppunittester sa_util NULL
-sa sal\qa\osl\security nmake - all sa_qa_osl_security sa_cppunittester sa_util NULL
-sa sal\qa\osl\process nmake - all sa_qa_osl_process sa_cppunittester sa_util NULL
-sa sal\qa\rtl\strings nmake - all sa_qa_rt_strings sa_cppunittester sa_util NULL
-sa sal\qa\rtl\oustringbuffer nmake - all sa_qa_rt_oustringbuffer sa_cppunittester sa_util NULL
-sa sal\qa\rtl\alloc nmake - all sa_qa_rt_alloc sa_cppunittester sa_util NULL
-sa sal\qa\rtl\crc32 nmake - all sa_qa_rtl_crc32 sa_cppunittester sa_util NULL
-sa sal\qa\rtl\cipher nmake - all sa_qa_rtl_cipher sa_cppunittester sa_util NULL
-sa sal\qa\rtl\doublelock nmake - all sa_qa_rtl_doublelock sa_cppunittester sa_util NULL
-sa sal\qa\rtl\locale nmake - all sa_qa_rtl_locale sa_cppunittester sa_util NULL
-sa sal\qa\sal nmake - all sa_qa_sal sa_cppunittester sa_util NULL
+sa sal\qa\ByteSequence nmake - all sa_qa_ByteSequence sa_cppunittester sa_util_saltextenc NULL
+sa sal\qa\OStringBuffer nmake - all sa_qa_OStringBuffer sa_cppunittester sa_util_saltextenc NULL
+sa sal\qa\osl\getsystempathfromfileurl nmake - all sa_qa_osl_getsystempathfromfileurl sa_cppunittester sa_util_saltextenc NULL
+sa sal\qa\osl\file nmake - u sa_qa_osl_file sa_cppunittester sa_util_saltextenc NULL
+sa sal\qa\osl\module nmake - u sa_qa_osl_module sa_cppunittester sa_util_saltextenc NULL
+sa sal\qa\osl\condition nmake - all sa_qa_osl_condition sa_cppunittester sa_util_saltextenc NULL
+sa sal\qa\osl\security nmake - all sa_qa_osl_security sa_cppunittester sa_util_saltextenc NULL
+sa sal\qa\osl\process nmake - all sa_qa_osl_process sa_cppunittester sa_util_saltextenc NULL
+sa sal\qa\rtl\strings nmake - all sa_qa_rt_strings sa_cppunittester sa_util_saltextenc NULL
+sa sal\qa\rtl\oustringbuffer nmake - all sa_qa_rt_oustringbuffer sa_cppunittester sa_util_saltextenc NULL
+sa sal\qa\rtl\alloc nmake - all sa_qa_rt_alloc sa_cppunittester sa_util_saltextenc NULL
+sa sal\qa\rtl\crc32 nmake - all sa_qa_rtl_crc32 sa_cppunittester sa_util_saltextenc NULL
+sa sal\qa\rtl\cipher nmake - all sa_qa_rtl_cipher sa_cppunittester sa_util_saltextenc NULL
+sa sal\qa\rtl\doublelock nmake - all sa_qa_rtl_doublelock sa_cppunittester sa_util_saltextenc NULL
+sa sal\qa\rtl\locale nmake - all sa_qa_rtl_locale sa_cppunittester sa_util_saltextenc NULL
+sa sal\qa\sal nmake - all sa_qa_sal sa_cppunittester sa_util_saltextenc NULL
 sa sal\qa\static nmake - u sal_qa_static sa_qa_ByteSequence sa_qa_OStringBuffer sa_qa_osl_file.u sa_qa_osl_condition sa_qa_osl_security sa_qa_rt_alloc sa_qa_rtl_crc32 sa_qa_rtl_cipher sa_qa_rtl_doublelock sa_qa_rtl_locale sa_qa_sal NULL
diff --git a/sal/prj/d.lst b/sal/prj/d.lst
index ac6bc63..f7ac525 100644
--- a/sal/prj/d.lst
+++ b/sal/prj/d.lst
@@ -22,10 +22,8 @@ mkdir: %_DEST%\inc\systools\win32
 symlink: %_DEST%\lib\libuno_sal.so.3 %_DEST%\lib\libuno_sal.so
 ..\%__SRC%\lib\libuno_sal.dylib.3 %_DEST%\lib\libuno_sal.dylib.3
 symlink: %_DEST%\lib\libuno_sal.dylib.3 %_DEST%\lib\libuno_sal.dylib
-..\%__SRC%\lib\libsal_textenc.so.3 %_DEST%\lib\libsal_textenc.so.3
-symlink: %_DEST%\lib\libsal_textenc.so.3 %_DEST%\lib\libsal_textenc.so
-..\%__SRC%\lib\libsal_textenc.dylib.3 %_DEST%\lib\libsal_textenc.dylib.3
-symlink: %_DEST%\lib\libsal_textenc.dylib.3 %_DEST%\lib\libsal_textenc.dylib
+..\%__SRC%\lib\libsal_textenc.so %_DEST%\lib\libsal_textenc.so
+..\%__SRC%\lib\libsal_textenc.dylib %_DEST%\lib\libsal_textenc.dylib
 ..\%__SRC%\lib\*.sl %_DEST%\lib\*.sl
 ..\%__SRC%\lib\*.a %_DEST%\lib\*.a
 
diff --git a/sal/textenc/makefile.mk b/sal/textenc/makefile.mk
index 7970ae0..09bf208 100644
--- a/sal/textenc/makefile.mk
+++ b/sal/textenc/makefile.mk
@@ -105,12 +105,6 @@ LIB1TARGET= $(SLB)$/$(TARGET).lib
 LIB1OBJFILES= $(SAL_OBJECTS) $(SAL_COMMON_OBJECTS)
 OBJTARGET=$(LB)$/$(TARGET).lib
 
-# be nicer to avoid DLLPRE
-.IF "$(GUI)" == "WNT"
-CDEFS+=-DPLUGIN_NAME=$(DLLPRE)sal_textenc$(UDK_MAJOR)$(DLLPOST)
-.ELSE
-CDEFS+=-DPLUGIN_NAME=$(DLLPRE)sal_textenc$(DLLPOST).$(UDK_MAJOR)
-.ENDIF
 LIB2TARGET= $(SLB)$/textenc_tables.lib
 LIB2OBJFILES= $(SAL_TABLES_OBJECTS) $(SAL_COMMON_OBJECTS)
 
diff --git a/sal/textenc/tables.cxx b/sal/textenc/tables.cxx
index 8197f68..3f96dcb 100644
--- a/sal/textenc/tables.cxx
+++ b/sal/textenc/tables.cxx
@@ -26,13 +26,9 @@
  *
  ************************************************************************/
 
-#ifdef IOS
-#define Impl_getTextEncodingData tables_Impl_getTextEncodingData
-#endif
+#include "sal/config.h"
 
-#ifndef INCLUDED_RTL_TEXTENC_GETTEXTENCODINGDATA_H
-#include "gettextencodingdata.h"
-#endif
+#include "sal/types.h"
 
 #ifndef INCLUDED_RTL_TEXTENC_TENCHELP_H
 #include "tenchelp.h"
@@ -129,8 +125,8 @@ static sal_uInt16 const aImplDoubleByteIdentifierTab[1] = { 0 };
 #include "convertiso2022kr.tab"
 #include "convertadobe.tab"
 
-ImplTextEncodingData const *
-Impl_getTextEncodingData(rtl_TextEncoding nEncoding)
+extern "C" ImplTextEncodingData const * sal_getFullTextEncodingData(
+    rtl_TextEncoding nEncoding)
 {
     static ImplTextEncodingData const * const aData[]
         = { NULL, /* DONTKNOW */
diff --git a/sal/textenc/textenc.cxx b/sal/textenc/textenc.cxx
index 0b245a0..c638cfd 100644
--- a/sal/textenc/textenc.cxx
+++ b/sal/textenc/textenc.cxx
@@ -28,6 +28,9 @@
 
 // MARKER(update_precomp.py): autogen include statement, do not remove
 #include "precompiled_sal.hxx"
+#include "sal/config.h"
+
+#include <cstdlib>
 
 /* TODO! This file should not be called textenc.c, because it is not the
    implementation of rtl/textenc.h.  Rather, it should be called
@@ -36,8 +39,13 @@
 #include "tenchelp.h"
 #include "rtl/textenc.h"
 #include <sal/macros.h>
+#include "boost/noncopyable.hpp"
+#include "osl/diagnose.h"
+#include "osl/module.hxx"
+#include "rtl/instance.hxx"
+#include "rtl/ustring.h"
 #include "rtl/ustring.hxx"
-#include "osl/module.h"
+#include "sal/types.h"
 
 #ifndef INCLUDED_STDDEF_H
 #include <stddef.h>
@@ -94,21 +102,71 @@ static sal_uInt16 const aImplDoubleByteIdentifierTab[1] = { 0 };
 #include "tcvtlat1.tab"
 #include "tcvtuni1.tab"
 
-extern "C" {
-        typedef ImplTextEncodingData const *(*TextEncodingFunction) (rtl_TextEncoding nEncoding);
+namespace {
+
+#if defined IOS
+
+extern "C" ImplTextEncodingData const * sal_getFullTextEncodingData(
+    rtl_TextEncoding); // from tables.cxx in sal_textenc library
+
+class FullTextEnocdingData: private boost::noncopyable {
+public:
+    ImplTextEncodingData const * get(rtl_TextEncoding encoding) {
+        return sal_getFullTextEncodingData(encoding);
+    }
 };
 
-// Yes - we should use the unpleasant to use templatized
-// sal:: doublecheckfoo thing here.
-#ifndef IOS
-static TextEncodingFunction pTables;
 #else
-extern "C" ImplTextEncodingData *tables_Impl_getTextEncodingData(rtl_TextEncoding);
-#define pTables tables_Impl_getTextEncodingData
+
+extern "C" {
+
+typedef ImplTextEncodingData const * TextEncodingFunction(rtl_TextEncoding);
+
+void SAL_CALL thisModule() {}
+
+};
+
+class FullTextEncodingData: private boost::noncopyable {
+public:
+    FullTextEncodingData() {
+        if (!module_.loadRelative(
+                &thisModule,
+                rtl::OUString(
+                    RTL_CONSTASCII_USTRINGPARAM(
+                        SAL_MODULENAME("sal_textenc")))))
+        {
+            OSL_TRACE("Loading sal_textenc library failed");
+            std::abort();
+        }
+        function_ = reinterpret_cast< TextEncodingFunction * >(
+            module_.getFunctionSymbol(
+                rtl::OUString(
+                    RTL_CONSTASCII_USTRINGPARAM(
+                        "sal_getFullTextEncodingData"))));
+        if (function_ == 0) {
+            OSL_TRACE(
+                "Obtaining sal_getFullTextEncodingData fuction from sal_textenc"
+                " library failed");
+            std::abort();
+        }
+    }
+
+    ImplTextEncodingData const * get(rtl_TextEncoding encoding) {
+        return (*function_)(encoding);
+    }
+
+private:
+    osl::Module module_;
+    TextEncodingFunction * function_;
+};
+
 #endif
 
-#define DOSTRING( x )  #x
-#define STRING( x )    DOSTRING( x )
+struct FullTextEncodingDataSingleton:
+    public rtl::Static< FullTextEncodingData, FullTextEncodingDataSingleton >
+{};
+
+}
 
 ImplTextEncodingData const *
 Impl_getTextEncodingData(rtl_TextEncoding nEncoding) SAL_THROW_EXTERN_C()
@@ -142,24 +200,7 @@ Impl_getTextEncodingData(rtl_TextEncoding nEncoding) SAL_THROW_EXTERN_C()
 // ----------------------------------------------
 #endif
         default:
-#ifndef IOS
-            if (!pTables)
-            {
-                static char const pName[] = STRING(PLUGIN_NAME);
-                oslModule aModule = osl_loadModuleAscii(pName, SAL_LOADMODULE_DEFAULT);
-
-                if(aModule)
-                {
-                    static char const pSymbol[] = "Impl_getTextEncodingData";
-                    pTables = (TextEncodingFunction)osl_getAsciiFunctionSymbol(aModule, pSymbol);
-                }
-            }
-#endif
-            if (pTables)
-                return pTables(nEncoding);
-//          else
-//              fprintf (stderr, "missing text encoding library for %d\n", nEncoding);
-            break;
+            return FullTextEncodingDataSingleton::get().get(nEncoding);
     }
     return NULL;
 }
diff --git a/sal/util/makefile.mk b/sal/util/makefile.mk
index 3a3a164..981f3cb 100644
--- a/sal/util/makefile.mk
+++ b/sal/util/makefile.mk
@@ -152,15 +152,6 @@ SHL1STDLIBS+=-lgcc
 .ENDIF
 .ENDIF
 
-SHL4DEPN+=$(SHL1TARGETN)
-SHL4LIBS=$(SLB)$/textenc_tables.lib
-SHL4TARGET=sal_textenc
-SHL4STDLIBS=$(SALLIB)
-SHL4VERSIONMAP=saltextenc.map
-
-SHL4DEF=$(MISC)$/$(SHL4TARGET).def
-DEF4NAME=$(SHL4TARGET)
-
 # --- Targets ------------------------------------------------------
 
 .ENDIF # $(header) != ""
diff --git a/sal/util/sal_textenc/makefile.mk b/sal/util/sal_textenc/makefile.mk
new file mode 100644
index 0000000..96a0540
--- /dev/null
+++ b/sal/util/sal_textenc/makefile.mk
@@ -0,0 +1,46 @@
+# Version: MPL 1.1 / GPLv3+ / LGPLv3+
+#
+# The contents of this file are subject to the Mozilla Public License Version
+# 1.1 (the "License"); you may not use this file except in compliance with
+# the License or as specified alternatively below. You may obtain a copy of
+# the License at http://www.mozilla.org/MPL/
+#
+# Software distributed under the License is distributed on an "AS IS" basis,
+# WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
+# for the specific language governing rights and limitations under the
+# License.
+#
+# Major Contributor(s):
+# [ Copyright (C) 2011 Stephan Bergmann, Red Hat Inc. <sbergman at redhat.com>
+#   (initial developer) ]
+#
+# All Rights Reserved.
+#
+# For minor contributions see the git repository.
+#
+# Alternatively, the contents of this file may be used under the terms of
+# either the GNU General Public License Version 3 or later (the "GPLv3+"), or
+# the GNU Lesser General Public License Version 3 or later (the "LGPLv3+"),
+# in which case the provisions of the GPLv3+ or the LGPLv3+ are applicable
+# instead of those above.
+
+PRJ = ../..
+PRJNAME = sal
+TARGET = sal_textenc
+
+# Should be VISIBILITY_HIDDEN=TRUE, but sal/textenc contains objects that end up
+# in both sal and sal_textenc libraries, so need to use a map file here for now.
+
+.INCLUDE: settings.mk
+
+# Should be DLLPRE= as it is loaded dynamically, but IOS links against it.
+
+SHL1IMPLIB = i$(SHL1TARGET)
+SHL1LIBS = $(SLB)/textenc_tables.lib
+SHL1RPATH = URELIB
+SHL1STDLIBS = $(SALLIB)
+SHL1TARGET = sal_textenc
+SHL1VERSIONMAP = saltextenc.map
+DEF1NAME = $(SHL1TARGET)
+
+.INCLUDE: target.mk
diff --git a/sal/util/sal_textenc/saltextenc.map b/sal/util/sal_textenc/saltextenc.map
new file mode 100644
index 0000000..45024c0
--- /dev/null
+++ b/sal/util/sal_textenc/saltextenc.map
@@ -0,0 +1,32 @@
+# Version: MPL 1.1 / GPLv3+ / LGPLv3+
+#
+# The contents of this file are subject to the Mozilla Public License Version
+# 1.1 (the "License"); you may not use this file except in compliance with
+# the License or as specified alternatively below. You may obtain a copy of
+# the License at http://www.mozilla.org/MPL/
+#
+# Software distributed under the License is distributed on an "AS IS" basis,
+# WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
+# for the specific language governing rights and limitations under the
+# License.
+#
+# Major Contributor(s):
+# [ Copyright (C) 2011 Stephan Bergmann, Red Hat Inc. <sbergman at redhat.com>
+#   (initial developer) ]
+#
+# All Rights Reserved.
+#
+# For minor contributions see the git repository.
+#
+# Alternatively, the contents of this file may be used under the terms of
+# either the GNU General Public License Version 3 or later (the "GPLv3+"), or
+# the GNU Lesser General Public License Version 3 or later (the "LGPLv3+"),
+# in which case the provisions of the GPLv3+ or the LGPLv3+ are applicable
+# instead of those above.
+
+UDK_3_0_0 {
+    global:
+        sal_getFullTextEncodingData;
+    local:
+        *;
+};
diff --git a/sal/util/saltextenc.map b/sal/util/saltextenc.map
deleted file mode 100644
index e88a0af..0000000
--- a/sal/util/saltextenc.map
+++ /dev/null
@@ -1,6 +0,0 @@
-UDK_3_0_0 {
-    global:
-    Impl_getTextEncodingData;
-    local:
-        *;
-};
diff --git a/scp2/source/ooo/ure.scp b/scp2/source/ooo/ure.scp
index 33ea472..6b30619 100644
--- a/scp2/source/ooo/ure.scp
+++ b/scp2/source/ooo/ure.scp
@@ -245,7 +245,7 @@ End
 File gid_File_Dl_Sal_TextEnc
     TXT_FILE_BODY;
     Dir = SCP2_URE_DL_DIR;
-    Name = SCP2_URE_DL_VER("sal_textenc", "3");
+    Name = SCP2_URE_DL_NORMAL("sal_textenc");
     Styles = (PACKED, VERSION_INDEPENDENT_COMP_ID);
 End
 
diff --git a/ure/source/README b/ure/source/README
index fdf1c7e..789fb46 100644
--- a/ure/source/README
+++ b/ure/source/README
@@ -80,6 +80,7 @@ Linux x86, Solaris x86, and Solaris SPARC:
 /opt/openoffice.org/ure/lib/libjpipe.so  [private]
 /opt/openoffice.org/ure/lib/libjuh.so  [private]
 /opt/openoffice.org/ure/lib/libjuhx.so  [private]
+/opt/openoffice.org/ure/lib/libsal_textenc.so  [private]
 /opt/openoffice.org/ure/lib/acceptor.uno.so  [private]
 /opt/openoffice.org/ure/lib/binaryurp.uno.so  [private]
 /opt/openoffice.org/ure/lib/bootstrap.uno.so  [private]
@@ -141,6 +142,7 @@ Program Files\URE\bin\jpipe.dll  [private]
 Program Files\URE\bin\jpipx.dll  [private]
 Program Files\URE\bin\juh.dll  [private]
 Program Files\URE\bin\juhx.dll  [private]
+Program Files\URE\bin\sal_textenc.dll  [private]
 Program Files\URE\bin\acceptor.uno.dll  [private]
 Program Files\URE\bin\binaryurp.uno.dll  [private]
 Program Files\URE\bin\bootstrap.uno.dll  [private]
commit 6560e48afa53a0ca1ab9417ac2637f8d64332375
Author: Stephan Bergmann <sbergman at redhat.com>
Date:   Wed Sep 21 11:52:26 2011 +0200

    Simplify code by letting get_app_path always include a final slash.

diff --git a/scp2/source/kde/file_kde.scp b/scp2/source/kde/file_kde.scp
index 3d139b7..4faff69 100644
--- a/scp2/source/kde/file_kde.scp
+++ b/scp2/source/kde/file_kde.scp
@@ -39,7 +39,7 @@ End
 File gid_File_Lib_Kde4be
     TXT_FILE_BODY;
     Styles = (PACKED);
-    Dir = gid_Dir_Program;
+    Dir = SCP2_OOO_BIN_DIR;
     Name = STRING(CONCAT2(kde4be1.uno,UNXSUFFIX));
 End
 #endif
diff --git a/scp2/source/ooo/file_library_ooo.scp b/scp2/source/ooo/file_library_ooo.scp
index cb63e78..ab305c5 100644
--- a/scp2/source/ooo/file_library_ooo.scp
+++ b/scp2/source/ooo/file_library_ooo.scp
@@ -504,7 +504,7 @@ End
 File gid_File_Lib_Fps_Kde4
     TXT_FILE_BODY;
     Styles = (PACKED);
-    Dir = gid_Dir_Program;
+    Dir = SCP2_OOO_BIN_DIR;
     Name = SPECIAL_COMPONENT_LIB_NAME(fps_kde4.uno);
 End
 #endif
@@ -514,7 +514,7 @@ End
 File gid_File_Lib_Fps_Kde
     TXT_FILE_BODY;
     Styles = (PACKED);
-    Dir = gid_Dir_Program;
+    Dir = SCP2_OOO_BIN_DIR;
     Name = SPECIAL_COMPONENT_LIB_NAME(fps_kde.uno);
 End
 File gid_File_Bin_KdeFilePicker
@@ -584,7 +584,7 @@ End
 File gid_File_Lib_Pixman
     TXT_FILE_BODY;
     Styles = (PACKED);
-    Dir = gid_Dir_Program;
+    Dir = SCP2_OOO_BIN_DIR;
   #ifdef UNX
     #ifdef MACOSX
        Name = "libpixman-1.a";
@@ -1014,7 +1014,7 @@ File gid_File_Lib_Vclplug_Kde4
     Name = LIBNAME(vclplug_kde4);
     TXT_FILE_BODY;
     Styles = (PACKED);
-    Dir = gid_Dir_Program;
+    Dir = SCP2_OOO_BIN_DIR;
 End
 #endif
 #endif
commit b403695bee563b54cd37e09a7b11b95a21a94958
Author: Stephan Bergmann <sbergman at redhat.com>
Date:   Wed Sep 21 09:06:07 2011 +0200

    Directly use version.lst instead of versionlist.mk.

diff --git a/solenv/inc/versionlist.mk b/solenv/inc/versionlist.mk
deleted file mode 100644
index 672df7b..0000000
--- a/solenv/inc/versionlist.mk
+++ /dev/null
@@ -1,30 +0,0 @@
-#*************************************************************************
-#
-# DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
-# 
-# Copyright 2000, 2010 Oracle and/or its affiliates.
-#
-# OpenOffice.org - a multi-platform office productivity suite
-#
-# This file is part of OpenOffice.org.
-#
-# OpenOffice.org is free software: you can redistribute it and/or modify
-# it under the terms of the GNU Lesser General Public License version 3
-# only, as published by the Free Software Foundation.
-#
-# OpenOffice.org is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU Lesser General Public License version 3 for more details
-# (a copy is included in the LICENSE file that accompanied this code).
-#
-# You should have received a copy of the GNU Lesser General Public License
-# version 3 along with OpenOffice.org.  If not, see
-# <http://www.openoffice.org/license.html>
-# for a copy of the LGPLv3 License.
-#
-#*************************************************************************
-
-.INCLUDE: version.lst
-
-.EXPORT : OOOBASEVERSIONMAJOR OOOBASEVERSIONMINOR OOOBASEVERSIONMICRO OOOBASEVERSIONDAY OOOBASEVERSIONMONTH OOOBASEVERSIONYEAR
diff --git a/solenv/makefile.mk b/solenv/makefile.mk
index c4a2d08..54d67db 100755
--- a/solenv/makefile.mk
+++ b/solenv/makefile.mk
@@ -32,7 +32,7 @@ TARGET=init
 # --- Settings ----------------------------------
 .INCLUDE : settings.mk
 .INCLUDE : target.mk
-.INCLUDE : versionlist.mk
+.INCLUDE : version.lst
 
 ALLTAR : $(INCCOM)/versionlist.hrc
 
commit 8ac8103e8ad317ba052312ff199f01b7a8f4fe43
Author: Stephan Bergmann <sbergman at redhat.com>
Date:   Wed Sep 21 08:36:49 2011 +0200

    Removed unused solenv/inc/version_so.hrc

diff --git a/solenv/inc/version_so.hrc b/solenv/inc/version_so.hrc
deleted file mode 100644
index 2e4db98..0000000
--- a/solenv/inc/version_so.hrc
+++ /dev/null
@@ -1,64 +0,0 @@
-/*************************************************************************
- *
- * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
- *
- * Copyright 2000, 2010 Oracle and/or its affiliates.
- *
- * OpenOffice.org - a multi-platform office productivity suite
- *
- * This file is part of OpenOffice.org.
- *
- * OpenOffice.org is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Lesser General Public License version 3
- * only, as published by the Free Software Foundation.
- *
- * OpenOffice.org is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Lesser General Public License version 3 for more details
- * (a copy is included in the LICENSE file that accompanied this code).
- *
- * You should have received a copy of the GNU Lesser General Public License
- * version 3 along with OpenOffice.org.  If not, see
- * <http://www.openoffice.org/license.html>
- * for a copy of the LGPLv3 License.
- *
- *************************************************************************/
-
-#include "versionlist.hrc"
-
-//#define VERVARIANT    0 // never define this one, will be provided by build environment (BUILD_ID)
-
-#define VER_FINAL       0
-
-#ifndef VER_FIRSTYEAR
-#define VER_FIRSTYEAR   VER_YEAR
-#endif
-
-#include "verinfo.hrc"
-
-#ifdef WIN32
-#define FOR_WIN_X " (32 Bit)"
-#else
-#define FOR_WIN_X ""
-#endif
-
-// -----------------------------------------------------------------------
-//                  language/character set specification table
-// -----------------------------------------------------------------------
-
-RCD_LANGUAGE rcdata
-{
-    "040904B0",     // USA -> Unicode
-    "040904E4",     // USA -> Windows, Multilingual
-    "04090000",     // USA -> 7-Bit-ASCII
-    0               // end of table
-}
-
-// version binary entry
-VS_VERSION_INFO rcdata
-{
-    0xF0, "sw", 0x0F, VER_YEAR, VER_MONTH, VER_DAY,
-    VERSION, SUBVERSION, VERVARIANT, VER_COUNT
-};
-


More information about the Libreoffice-commits mailing list
diff --git a/desktop/unx/source/start.c b/desktop/unx/source/start.c
index 58692c4..37b407b 100755
--- a/desktop/unx/source/start.c
+++ b/desktop/unx/source/start.c
@@ -138,7 +138,7 @@ child_spawn ( Args *args, sal_Bool bAllArgs, sal_Bool bWithStatus )
     /* application name */
     rtl_uString_newFromAscii( &pApp, "file://" );
     rtl_uString_newConcat( &pApp, pApp, args->pAppPath );
-    rtl_uString_newFromAscii( &pTmp, "/soffice.bin" );
+    rtl_uString_newFromAscii( &pTmp, "soffice.bin" );
     rtl_uString_newConcat( &pApp, pApp, pTmp );
     rtl_uString_release( pTmp );
     pTmp = NULL;
@@ -210,12 +210,13 @@ child_get_exit_code (ChildInfo *info)
 
 typedef enum { ProgressContinue, ProgressRestart, ProgressExit } ProgressStatus;
 
 /* Path of the application. */
 static rtl_uString *
 get_app_path( const char *pAppExec )
 {
     char pRealPath[PATH_MAX];
     rtl_uString *pResult;
+    sal_Int32 len;
 
     char *pOrigPath = strdup( pAppExec );
     char *pPath = dirname( pOrigPath );
@@ -224,6 +225,15 @@ get_app_path( const char *pAppExec )
     pResult = charp_to_ustr( pRealPath );
     free( pOrigPath );
 
+    len = rtl_uString_getLength(pResult);
+    if (len > 0 && rtl_uString_getStr(pResult)[len - 1] != '/')
+    {
+        rtl_uString *pSlash = NULL;
+        rtl_uString_newFromAscii(&pSlash, "/");
+        rtl_uString_newConcat(&pResult, pResult, pSlash);
+        rtl_uString_release(pSlash);
+    }
+
     return pResult;
 }
 
@@ -289,7 +299,6 @@ get_pipe_path( rtl_uString *pAppPath )
     /* setup bootstrap filename */
     rtl_uString_newFromAscii( &pPath, "file://" );
     rtl_uString_newConcat( &pPath, pPath, pAppPath );
-    rtl_uString_newFromAscii( &pTmp, "/" );
     rtl_uString_newConcat( &pPath, pPath, pTmp );
     rtl_uString_newFromAscii( &pTmp, SAL_CONFIGFILE( "bootstrap" ) );
     rtl_uString_newConcat( &pPath, pPath, pTmp );
@@ -557,23 +566,23 @@ load_splash_image( rtl_uString *pUAppPath )
     pSuffix = pBuffer + pAppPath->length;
     rtl_string_release( pAppPath );
 
-    strcpy (pSuffix, "/edition/intro");
+    strcpy (pSuffix, "edition/intro");
     strcat (pSuffix, pLocale);
     strcat (pSuffix, IMG_SUFFIX);
     if ( splash_load_bmp( pBuffer ) )
         goto cleanup;
 
-    strcpy (pSuffix, "/edition/intro" IMG_SUFFIX);
+    strcpy (pSuffix, "edition/intro" IMG_SUFFIX);
     if ( splash_load_bmp( pBuffer ) )
         goto cleanup;
 
-    strcpy (pSuffix, "/intro");
+    strcpy (pSuffix, "intro");
     strcat (pSuffix, pLocale);
     strcat (pSuffix, IMG_SUFFIX);
     if ( splash_load_bmp( pBuffer ) )
         goto cleanup;
 
-    strcpy (pSuffix, "/intro" IMG_SUFFIX);
+    strcpy (pSuffix, "intro" IMG_SUFFIX);
     if ( splash_load_bmp( pBuffer ) )
         goto cleanup;
 
@@ -625,7 +634,6 @@ load_splash_defaults( rtl_uString *pAppPath, sal_Bool *bNoDefaults )
     /* costruct the sofficerc file location */
     rtl_uString_newFromAscii( &pSettings, "file://" );
     rtl_uString_newConcat( &pSettings, pSettings, pAppPath );
-    rtl_uString_newFromAscii( &pTmp, "/" );
     rtl_uString_newConcat( &pSettings, pSettings, pTmp );
     rtl_uString_newFromAscii( &pTmp, SAL_CONFIGFILE( "soffice" ) );
     rtl_uString_newConcat( &pSettings, pSettings, pTmp );
@@ -735,7 +743,7 @@ system_checks( void )
 extern int pagein_execute (int argc, char **argv);
 
 #ifndef MACOSX
-#define REL_PATH "/../basis-link/program/"
+#define REL_PATH "../basis-link/program/"
 static char *build_pagein_path (Args *args, const char *pagein_name)
 {
     char *path;
@@ -832,7 +840,7 @@ exec_javaldx (Args *args)
     rtl_uString_newFromAscii( &pTmp, "-env:INIFILENAME=vnd.sun.star.pathname:" );
     rtl_uString_newConcat( &pTmp, pTmp, args->pAppPath );
     pTmp2 = NULL;
-    rtl_uString_newFromAscii( &pTmp2, "/redirectrc" );
+    rtl_uString_newFromAscii( &pTmp2, "redirectrc" );
     rtl_uString_newConcat( &pTmp, pTmp, pTmp2 );
     ppArgs[nArgs] = pTmp;
     rtl_uString_release (pTmp2);
@@ -847,7 +855,7 @@ exec_javaldx (Args *args)
     rtl_uString_newFromAscii( &pApp, "file://" );
     rtl_uString_newConcat( &pApp, pApp, args->pAppPath );
     pTmp = NULL;
-    rtl_uString_newFromAscii( &pTmp, "/../basis-link/ure-link/bin/javaldx" );
+    rtl_uString_newFromAscii( &pTmp, "../basis-link/ure-link/bin/javaldx" );
     rtl_uString_newConcat( &pApp, pApp, pTmp );
     rtl_uString_release( pTmp );
 
@@ -210,12 +210,13 @@ child_get_exit_code (ChildInfo *info)
 typedef enum { ProgressContinue, ProgressRestart, ProgressExit } ProgressStatus;
 
-/* Path of the application. */
+/* Path of the application, with trailing slash. */
 static rtl_uString *
 get_app_path( const char *pAppExec )
commit 149deaca814f21247497b9f7830567044682ecfa
Author: Stephan Bergmann <sbergman at redhat.com>
Date:   Wed Sep 21 09:24:44 2011 +0200

    Correctly use SCP2_OOO_BIN_DIR for libs in basis layer.
